# HelMet Finland scraper
#
# Copyright  1999-2015 Readerware Corporation.  All Rights Reserved.

import  os
import  string

import  rw

from    com.readerware.http import HTTPConnection

from    rwsupport import searchFor
from    rwsupport import searchForPlus
from    rwsupport import stripText
from    rwsupport import appendComment
from    rwsupport import calcISBN10CheckDigit

from    jarray import zeros, array
from    java.lang import String
from    java.util import Date


def extract(source):
    # Defaults
    rw.setPublicationPlace("Finland")



    # Main extraction
    titleTag = "class=\"bibDisplayTitle\""
    authorTag = ">Author<"
    pubTag = ">Publication data<"
    dimensionsTag = ">Physical description<"
    isbnTag = ">ISBN<"
    subtitleTag = ">Additional title<"
    keywordsTag = ">Subject<"

    i = string.find(source, "Toiminnot ja ohjeet")

    if i != -1:
        titleTag = "class=\"bibDisplayTitle\""
        authorTag = ">Tekij<"
        pubTag = ">Julkaisutiedot<"
        dimensionsTag = ">Ulkoasu<"
        isbnTag = ">ISBN<"
        subtitleTag = ">Muu nimeke<"
        keywordsTag = ">Asiasana<"



    source = searchForPlus(source, "class=\"bibPager\"")


    # Find Author
    authorList = []
    i = string.find(source, authorTag)

    if i != -1:
        authors = searchForPlus(source, authorTag)
        i = string.find(authors, "</td>")
        authors = stripText(authors[0:i])

        while (searchFor(authors, "href=\"") != None):
            authors = searchForPlus(authors, "href=\"")
            authors = searchForPlus(authors, "\">")
            i = string.find(authors, "<")
            author = stripText(authors[0:i])

            authorList.append(author)

    rw.setAuthors(authorList)


    # Find Title
    title = searchForPlus(source, titleTag)
    title = searchForPlus(title, "<strong>")
    i = string.find(title, "<")
    title = stripText(title[0:i])

    i = string.rfind(title, " / ")

    if i != -1:
        title = stripText(title[0:i])

    rw.setTitle(title)


    # Find Publisher
    i = string.find(source, pubTag)

    if i != -1:
        date = ""
        copyDate = ""
        publisher = searchForPlus(source, pubTag)
        publisher = searchForPlus(publisher, "\">")
        i = string.find(publisher, "<")
        publisher = stripText(publisher[0:i])

        i = string.rfind(publisher, " : ")

        if i != -1:
            place = stripText(publisher[0:i])
            publisher = stripText(publisher[i+2:])
            rw.setPublicationPlace(place)

        i = string.find(publisher, ", ")

        if i != -1:
            date = stripText(publisher[i+1:])
            publisher = stripText(publisher[0:i])

            if date.startswith("cop.") == 1:
                copyDate = stripText(date[4:])
                date = "";

        rw.setPublisher(publisher)

        i = string.find(date, " ")

        if i != -1:
            date = stripText(date[0:i])

        rw.setReleaseDate(date)

        i = string.find(copyDate, " ")

        if i != -1:
            copyDate = stripText(copyDate[0:i])

        rw.setCopyrightDate(copyDate)

            


    # Find Pages/Dimensions
    i = string.find(source, dimensionsTag)

    if i != -1:
        attr = searchForPlus(source, dimensionsTag)
        attr = searchForPlus(attr, "\">")
        i = string.find(attr, "<")
        attr = stripText(attr[0:i])

        i = string.find(attr, " s.")

        if i != -1:
            pages = stripText(attr[0:i])

            i = string.find(pages, ",")

            if i != -1:
                pages = stripText(attr[0:i])

            rw.setPages(pages)

        i = string.find(attr, "&#59;")

        if i != -1:
            attr = stripText(attr[i+5:])

        i = string.find(attr, " cm")

        if i != -1:
            dimensions = stripText(attr[0:i+3])
            rw.setDimensions(dimensions)


    # Series
    i = string.find(source, ">Series:<")

    if i != -1:
        series = searchForPlus(source, ">Series:<")
        series = searchForPlus(series, "<TD")
        series = searchForPlus(series, ">")
        i = string.find(series, "<")
        series = stripText(series[0:i])


    # Find ISBN
    i = string.find(source, isbnTag)

    if i != -1:
        isbn = searchForPlus(source, isbnTag)
        isbn = searchForPlus(isbn, "\">")
        i = string.find(isbn, "<")
        isbn = stripText(isbn[0:i])

        i = string.find(isbn, "(nid.)")

        if i != -1:
            rw.setFormat("Paperback")

        i = string.find(isbn, "(hft.)")

        if i != -1:
            rw.setFormat("Paperback")

        i = string.find(isbn, "(sid.)")

        if i != -1:
            rw.setFormat("Hardcover")

        i = string.find(isbn, "(inb.)")

        if i != -1:
            rw.setFormat("Hardcover")

        i = string.find(isbn, "(")

        if i != -1:
            isbn = stripText(isbn[0:i])

        rw.setISBN(isbn)


    # Find Subtitle
    i = string.find(source, subtitleTag)

    if i != -1:
        subtitle = searchForPlus(source, subtitleTag)
        subtitle = searchForPlus(subtitle, "href=\"")
        subtitle = searchForPlus(subtitle, "\">")
        i = string.find(subtitle, "<")
        subtitle = stripText(subtitle[0:i])
        rw.setSubtitle(subtitle)



    # Find Keywords
    i = string.find(source, keywordsTag)

    if i != -1:
        keywords = ""
        category = ""
        temp = searchForPlus(source, keywordsTag)
        i = string.find(temp, "</table>")
        temp = stripText(temp[0:i])

        i = string.find(temp, "next row for fieldtag=j")

        if i != -1:
            temp = stripText(temp[0:i])

        i = string.find(temp, "next row for fieldtag=q")

        if i != -1:
            temp = stripText(temp[0:i])

        i = string.find(temp, "next row for fieldtag=v")

        if i != -1:
            temp = stripText(temp[0:i])

        while (searchFor(temp, "href=\"") != None):
            temp = searchForPlus(temp, "href=\"")
            temp = searchForPlus(temp, "\">")
            i = string.find(temp, "<")
            keyword = stripText(temp[0:i])

            i = string.find(keyword, "(")

            if i != -1:
                keyword = stripText(keyword[0:i])

            if keywords == "":
                keywords = keyword
                category = keyword
            else:
                keywords = keywords + ", " + keyword

        rw.setKeywords(keywords)
        rw.setCategory1(category)




try:
    rw.setBookObject(Book)
    extract(source)
finally:
    if os.path.exists(rw.getDocsDir() + "rwuserexit.py"):
        execfile(rw.getDocsDir() + "rwuserexit.py") in globals()
